Sync from Asana — django-asana 1.3.5 documentation

# Sync from Asana

The django management command sync_from_asana

class `djasana.management.commands.sync_from_asana.` `Command`(stdout=None, stderr=None, no_color=False)

  Sync data from Asana to the database

  `add_arguments`(parser)

    Entry point for subclassed commands to add custom arguments.

  `handle`(*args, **options)

    The actual logic of the command. Subclasses must implement this method.